@@ -2,7 +2,7 @@
  * ProGuard -- shrinking, optimization, obfuscation, and preverification
  *             of Java bytecode.
  *
- * Copyright (c) 2002-2012 Eric Lafortune (eric@graphics.cornell.edu)
+ * Copyright (c) 2002-2016 Eric Lafortune @ GuardSquare
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -58,7 +58,7 @@ public class ArrayElementValue extends ElementValue
 
     // Implementations for ElementValue.
 
-    public int getTag()
+    public char getTag()
     {
         return ClassConstants.ELEMENT_VALUE_ARRAY;
     }
